@@ -8,7 +8,7 @@ context("isomap")
 
 test_that("check vs vegan isomap", {
 
-    eps <- 1e-13
+    eps <- 1e-8
     a <- loadDataSet("3D S Curve", n = 200)
 
     vegiso <- vegan::isomap(dist(getData(a)), k = 8, ndim = 2)
@@ -21,12 +21,27 @@ test_that("check vs vegan isomap", {
     ## expect_equivalent(drdy, vegy)
 
     err1 <- max(abs(drdy - vegy))
+
     drdy[, 2] <- -drdy[, 2]
     err2 <- max(abs(drdy - vegy))
-    err <- min(err1, err2)
+
+    drdy[, 1] <- -drdy[, 1]
+    err3 <- max(abs(drdy - vegy))
+
+    drdy[, 2] <- -drdy[, 2]
+    err4 <- max(abs(drdy - vegy))
+
+    err <- min(err1, err2, err3, err4)
 
     expect_true(err < eps, info = paste0("err = ", err,
                                          ", eps = ", eps,
                                          ", expected err < eps"))
 
 })
+
+
+test_that("check other.data", {
+  a <- loadDataSet("3D S Curve", n = 200)
+  drdiso <- embed(a, "Isomap", knn = 8, ndim = 2, get_geod = TRUE)
+  expect_true(inherits(getOtherData(drdiso)$geod, "dist"))
+})
